pyhsm.exception.YHSM_InputTooLong

Package pyhsm :: Module exception :: Class YHSM_InputTooLong |
[frames] | no frames]

# Class YHSM_InputTooLong

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                          YHSM_Error --+
                                       |
                                      YHSM_InputTooLong

Exception raised for too long input to some function.

Instance Methods
__init__(self, name, expected, size) x.__init__(...) initializes x; see help(type(x)) for signature |
Inherited from `YHSM_Error`: `__str__` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Instance Variables
Inherited from `YHSM_Error`: `reason`

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__(self, name, expected, size) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)